#!/bin/python

if __name__ == "__main__":
    from picomc import main

    main()
